# -*- coding: utf-8 -*-

from maintenance_mode import settings


def get_maintenance_mode():

    try:
        handler = open(settings.MAINTENANCE_MODE_STATE_FILE_PATH, 'r+')
        value = 0

        try:
            value = int(handler.read())

        except ValueError:
            pass

        handler.close()

        return value

    except IOError:

        return False


def set_maintenance_mode(value):

    handler = open(settings.MAINTENANCE_MODE_STATE_FILE_PATH, 'w+')
    handler.write(str(int(value)))
    handler.close()




# -*- coding: utf-8 -*-

import django
from django.core.urlresolvers import NoReverseMatch, resolve, reverse
from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response

if django.VERSION < (1, 8):
    from django.template import RequestContext

from django.utils.cache import add_never_cache_headers

from maintenance_mode import core
from maintenance_mode import settings


class MaintenanceModeMiddleware(object):

    def process_request(self, request):

        if settings.MAINTENANCE_MODE or core.get_maintenance_mode():

            try:
                url_off = reverse('maintenance_mode_off')

                resolve(url_off)

                if url_off == request.path_info:
                    return None

            except NoReverseMatch:
                #maintenance_mode.urls not added
                pass

            if hasattr(request, 'user'):

                if settings.MAINTENANCE_MODE_IGNORE_STAFF and request.user.is_staff:
                    return None

                if settings.MAINTENANCE_MODE_IGNORE_SUPERUSER and request.user.is_superuser:
                    return None

            for ip_address_re in settings.MAINTENANCE_MODE_IGNORE_IP_ADDRESSES_RE:

                if ip_address_re.match(request.META['REMOTE_ADDR']):
                    return None

            for url_re in settings.MAINTENANCE_MODE_IGNORE_URLS_RE:

                if url_re.match(request.path_info):
                    return None

            if settings.MAINTENANCE_MODE_REDIRECT_URL:
                return HttpResponseRedirect(settings.MAINTENANCE_MODE_REDIRECT_URL)
            else:
                if django.VERSION < (1, 8):
                    response = render_to_response(settings.MAINTENANCE_MODE_TEMPLATE, self.get_request_context(request), context_instance=RequestContext(request), content_type='text/html', status=503)
                else:
                    response = render_to_response(settings.MAINTENANCE_MODE_TEMPLATE, self.get_request_context(request), content_type='text/html', status=503)

                add_never_cache_headers(response)
                return response
        else:
            return None


    def get_request_context(self, request):

        if settings.MAINTENANCE_MODE_TEMPLATE_CONTEXT:

            from importlib import import_module

            func_path = settings.MAINTENANCE_MODE_TEMPLATE_CONTEXT
            mod_name, func_name = func_path.rsplit('.',1)
            mod = import_module(mod_name)
            func = getattr(mod, func_name)

            return func(request = request)
        else:
            return {}




# -*- coding: utf-8 -*-

from django.conf import settings

import os
import re


MAINTENANCE_MODE = getattr(settings, 'MAINTENANCE_MODE', False)
MAINTENANCE_MODE_STATE_FILE_PATH = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'maintenance_mode_state.txt')

MAINTENANCE_MODE_IGNORE_STAFF = getattr(settings, 'MAINTENANCE_MODE_IGNORE_STAFF', False)
MAINTENANCE_MODE_IGNORE_SUPERUSER = getattr(settings, 'MAINTENANCE_MODE_IGNORE_SUPERUSER', False)

MAINTENANCE_MODE_IGNORE_IP_ADDRESSES = getattr(settings, 'MAINTENANCE_MODE_IGNORE_IP_ADDRESSES', ())
MAINTENANCE_MODE_IGNORE_IP_ADDRESSES_RE = tuple([re.compile(ip_address) for ip_address in MAINTENANCE_MODE_IGNORE_IP_ADDRESSES])

MAINTENANCE_MODE_IGNORE_URLS = getattr(settings, 'MAINTENANCE_MODE_IGNORE_URLS', ())
MAINTENANCE_MODE_IGNORE_URLS_RE = tuple([re.compile(url) for url in MAINTENANCE_MODE_IGNORE_URLS])

MAINTENANCE_MODE_REDIRECT_URL = getattr(settings, 'MAINTENANCE_MODE_REDIRECT_URL', None)

if MAINTENANCE_MODE_REDIRECT_URL and MAINTENANCE_MODE_REDIRECT_URL[0:4].lower() != 'http':
    raise ValueError('MAINTENANCE_MODE_REDIRECT_URL should be an absolute url: %s' % MAINTENANCE_MODE_REDIRECT_URL)

MAINTENANCE_MODE_TEMPLATE = getattr(settings, 'MAINTENANCE_MODE_TEMPLATE', '503.html')
MAINTENANCE_MODE_TEMPLATE_CONTEXT = getattr(settings, 'MAINTENANCE_MODE_TEMPLATE_CONTEXT', None)




# -*- coding: utf-8 -*-

from django.conf.urls import url

from maintenance_mode import views


urlpatterns = [
    url(r'^off/$', views.maintenance_mode_off, name='maintenance_mode_off'),
    url(r'^on/$', views.maintenance_mode_on, name='maintenance_mode_on'),
]




# -*- coding: utf-8 -*-

from django.http import HttpResponseRedirect

from maintenance_mode import core


def maintenance_mode_off(request):

    if request.user.is_superuser:

        core.set_maintenance_mode(False)

    return HttpResponseRedirect('/')


def maintenance_mode_on(request):

    if request.user.is_superuser:

        core.set_maintenance_mode(True)

    return HttpResponseRedirect('/')




# -*- coding: utf-8 -*-

from __future__ import absolute_import

from django.core.management.base import BaseCommand

from maintenance_mode import core


class Command(BaseCommand):
    
    args = '<on|off>'
    help = 'run python manage.py maintenance_mode %s to change maintenance-mode state' % args
    
    def handle(self, *args, **options):
        
        if len(args) > 0:
            
            arg_value = args[0].lower()
            
            if arg_value in ['on', 'yes', 'true', '1']:
                core.set_maintenance_mode(True)
                return
                
            elif arg_value in ['off', 'no', 'false', '0']:
                core.set_maintenance_mode(False)
                return
                
        print(self.help)
        
        



#!/usr/bin/env python
from setuptools import setup, find_packages

exec(open('maintenance_mode/version.py').read())

setup(
    name='django-maintenance-mode',
    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),
    version=__version__,
    description='django-maintenance-mode shows a 503 error page when maintenance-mode is on.',
    author='Fabio Caccamo',
    author_email='fabio.caccamo@gmail.com',
    url='https://github.com/fabiocaccamo/django-maintenance-mode',
    download_url='https://github.com/fabiocaccamo/django-maintenance-mode/archive/%s.tar.gz' % __version__,
    keywords = ['django', 'maintenance', 'mode', 'offline', 'under', '503', 'service', 'temporarily', 'unavailable'],
    requires=['django(>=1.4)'],
    classifiers=[]
)

